@@ -5,9 +5,12 @@ aggregation.brier <- function(full.data=NULL, response, x, model, cplx=NULL,  ty
    if(class(model)[1]=="penfit"){
       probs <- predict(model, data=data, penalized=x, ...)
    } else {
+if(class(model)[1] == "glm") {
+            probs <- predict(model, newdata = data, penalized = x, type = "response", ...)
+        } else {
       probs <- predict(model, data=data, type="response", ...)
    }
-
+}
    type <- match.arg(type)
    if (type=="apparent"){
       brier.score <- sum((probs-response)^2)/length(response)
